Project: flame_python_tools
=====
The project contains the following subfolders:  
1. [./code](./code/) mne-python-style code for running flame algorithm. <br>
2. [./code_analysis](./code_analysis) code for the analysis within flame pubblication. <br>
3. [./work_in_progress](./work_in_progress) work-in-progress study on the combination of eeg and meg <br>

Author 
-----
Sara Sommariva (sara.sommariva@aalto.fi)